@@ -1,11 +1,13 @@
 package App::EditorTools::Command::IntroduceTemporaryVariable;
 
+# ABSTRACT:  Introduce a Temporary Variable
+
 use strict;
 use warnings;
 
 use App::EditorTools -command;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 sub opt_spec {
     return (
@@ -52,9 +54,17 @@ sub execute {
 
 1;
 
+__END__
+
+=pod
+
 =head1 NAME
 
-App::EditorTools::Command::IntroduceTemporaryVariable - Introduce a Temporary Variable 
+App::EditorTools::Command::IntroduceTemporaryVariable - Introduce a Temporary Variable
+
+=head1 VERSION
+
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -66,10 +76,9 @@ Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010 by Mark Grimes
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.2 or,
-at your option, any later version of Perl 5 you may have available.
+This software is copyright (c) 2013 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
