@@ -1,12 +1,14 @@
 package App::EditorTools::Command::RenamePackage;
 
+# ABSTRACT: Rename the package
+
 use strict;
 use warnings;
 use Path::Class;
 
 use App::EditorTools -command;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 sub opt_spec {
     return ( [ "name|n=s", "The new name of the package", ] );
@@ -32,24 +34,38 @@ sub execute {
 
 1;
 
+__END__
+
+=pod
+
 =head1 NAME
 
-App::EditorTools::Command::RenamePackage - Rename the Package Based 
+App::EditorTools::Command::RenamePackage - Rename the package
+
+=head1 VERSION
+
+version 0.18
 
 =head1 DESCRIPTION
 
 See L<App::EditorTools> for documentation.
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 AUTHOR
 
 Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010 by Mark Grimes
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.2 or,
-at your option, any later version of Perl 5 you may have available.
+This software is copyright (c) 2013 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
